@@ -13,12 +13,12 @@ Test::Group - Group together related tests in a test suite
 
 =head1 VERSION
 
-Test::Group version 0.16
+Test::Group version 0.17
 
 =cut
 
 use vars qw($VERSION);
-$VERSION = '0.16';
+$VERSION = '0.17';
 
 =head1 SYNOPSIS
 
@@ -306,6 +306,10 @@ L<Test::More/subtest> functionality.
 A simple plugin interface allows module authors to write extensions
 to I<Test::Group>.  See L<Test::Group::Extending> for details.
 
+The following extensions are distributed with I<Test::Group>:
+
+L<Test::Group::Plan>, L<Test::Group::NoWarnings> 
+
 =cut
 
 use 5.004;
@@ -473,7 +477,7 @@ Equivalent to:
 
 =head3 begin_skipping_tests ()
 
-    begin_skipping_tests
+    begin_skipping_tests;
     begin_skipping_tests "reason";
 
 Skips all subsequent groups of tests until blocked by
